/* SAS code used to estimate log-linear trend with autocorrelated, ar(1), errors */
/*    and calculate p-values for equivalence tests.  */

/*  The equivalence interval is (-0.0346, 0.0346).  */
/*  The endpoints of the equivalence interval are used in the calculation of */
/*     lt and ut in the last data step.  */

data trend; 
  infile 'Ambystoma.txt' missover;
  input sp $ year abdn;

  labdn=log(abdn+1);
  year = year - 1975;

proc mixed data = trend;
  by sp;
   
  model labdn=year  /cl alpha=0.10 ddfm = kr;
  repeated /type=ar(1) subject=intercept ;
  
  ods output SolutionF = parms;

  title 'ar(1) errors, thru 2002';
  run;

proc print data = parms;
 
data tests;
  set parms;
  
  file 'ests.txt';
  
  if _n_ =  1 then put 'spp est se df t pval lci uci lt ut lp up';
  
  if effect = 'year' then do;
    lt =  (estimate - (-0.0346))/stderr;
    lp = 1-probt(lt,df);
    ut = (estimate -0.0346)/stderr;
    up = probt(ut,df);
    
    put sp estimate stderr df tvalue probt lower upper lt ut lp up;
    output;
    end;
    
proc print;
  title 'Equivalence test results for each species';
  run;
      
